<?php

namespace Drupal\notification;

use \Drupal\Core\Datetime\DrupalDateTime;
use \Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;


class NotificationManager {

    public function getNotifications(): array {
        $now = new DrupalDateTime();
        $now = $now->format(DateTimeItemInterface::DATETIME_STORAGE_FORMAT);
        $roles = \Drupal::currentUser()->getRoles();
        $node = \Drupal::routeMatch()->getParameter("node");

        $query = \Drupal::entityQuery('notification')->accessCheck(FALSE);
        $query->condition('status', 1);

        $condition_start_date = $query->orConditionGroup();
        $condition_start_date->notExists('start_date');
        $condition_start_date->condition('start_date', $now, '<=');
        $query->condition($condition_start_date);

        $condition_end_date = $query->orConditionGroup();
        $condition_end_date->notExists('end_date');
        $condition_end_date->condition('end_date', $now, '>=');
        $query->condition($condition_end_date);

        $condition_roles = $query->orConditionGroup();
        $condition_roles->notExists('roles');
        foreach($roles as $role) {
            $condition_roles->condition('roles', $role, 'IN');
        }
        $query->condition($condition_roles);

        $condition_content_types = $query->orConditionGroup();
        $condition_content_types->notExists('content_types');
        if($node) {
            $condition_content_types->condition('content_types', $node->bundle(), 'IN');
        }
        $query->condition($condition_content_types);

        $notificationIds = $query->execute();
        $notifications = \Drupal::entityTypeManager()->getStorage("notification")->loadMultiple($notificationIds);

        return $notifications;
    }

}